| rqualify | R Documentation |
Run IQ-OQ on an installation of R software
rqualify(
path_save,
setup_tinytex = TRUE,
setup_pandoc = TRUE,
render_latex = TRUE,
engine = "latex",
verbose = TRUE
)
path_save |
Character. Path to save the R-validation folder. Ensure a folder named R-validation does not already exist at this location. |
setup_tinytex |
Logical. If TRUE, sets up TinyTeX for LaTeX document
generation. Note, this does not install the tinytex R package, but the TinyTeX
LaTeX bundle. It is a convenient wrapper for installing TinyTeX using
|
setup_pandoc |
Logical. If TRUE, sets up pandoc for document conversion.
Note, this does not install the pandoc R package, but the Pandoc software. It
is a convenient wrapper around |
render_latex |
Logical. If TRUE, renders the generated LaTeX file to PDF using
|
engine |
Character. Engine to generate the PDF. Either |
verbose |
Logical. If TRUE, prints progress messages to the console. |
This function creates a folder named R-validation at the specified path,
and generates a PDF report. Depending on the engine argument, the report
can be generated with LaTeX or with typst (via Quarto). If engine = "latex",
it allows users to conveniently install TinyTeX and Pandox, render an RMarkdown
file to LaTeX, compiles the LaTeX to PDF, and saves the output in the created
folder. If engine = "quarto", it instead uses Quarto to render the report
via typst. Quarto, pandoc, and typst are all part of the standard RStudio
installation, therefore requiring no additional software installation.
The validation process involves running a series of tests on the R installation and
can be quite time consuming. The function will print progress messages to the
console if verbose is set to TRUE.
The following steps are carried out using default arguments:
Create the folder tree R-validation/IQ-OQ-TestOutput at path_save
Install TinyTeX and necessary LaTeX packages
Install Pandoc
Copy RMarkdown validation file to the R-validation folder
Execute the IQ-OQ by rendering the RMarkdown file to LaTeX
Compile the LaTeX file to pdf
The path to the R-validation folder. The primary purpose of this function is its side effects, rendering an RMarkdown document.
# Render the R-validation report, must have TinyTeX and Pandoc installed for
# this example, otherwise set setup_tinytex and setup_pandoc to TRUE.
rqualify(path_save = tempdir(),
setup_tinytex = FALSE,
setup_pandoc = FALSE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.